summaryrefslogtreecommitdiffstats
path: root/twin/clients/quartz/quartz.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'twin/clients/quartz/quartz.cpp')
-rw-r--r--twin/clients/quartz/quartz.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/twin/clients/quartz/quartz.cpp b/twin/clients/quartz/quartz.cpp
index 21b4c039c..d0b8974cf 100644
--- a/twin/clients/quartz/quartz.cpp
+++ b/twin/clients/quartz/quartz.cpp
@@ -291,18 +291,18 @@ void QuartzHandler::drawBlocks( KPixmap *pi, KPixmap &p, const TQColor &c1, cons
void QuartzHandler::createPixmaps()
{
// Obtain titlebar blend colours, and create the block stuff on pixmaps.
- TQColorGroup g2 = options()->colorGroup(ColorTitleBlend, true);
+ TQColorGroup g2 = options()->tqcolorGroup(ColorTitleBlend, true);
TQColor c2 = g2.background();
- g2 = options()->colorGroup(ColorTitleBar, true );
+ g2 = options()->tqcolorGroup(ColorTitleBar, true );
TQColor c = g2.background().light(130);
titleBlocks = new KPixmap();
titleBlocks->resize( normalTitleHeight*25/18, normalTitleHeight );
drawBlocks( titleBlocks, *titleBlocks, c, c2 );
- g2 = options()->colorGroup(ColorTitleBlend, false);
+ g2 = options()->tqcolorGroup(ColorTitleBlend, false);
c2 = g2.background();
- g2 = options()->colorGroup(ColorTitleBar, false );
+ g2 = options()->tqcolorGroup(ColorTitleBar, false );
c = g2.background().light(130);
ititleBlocks = new KPixmap();
@@ -313,9 +313,9 @@ void QuartzHandler::createPixmaps()
TQColorGroup g;
TQPainter p;
- g = options()->colorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, true );
+ g = options()->tqcolorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, true );
c = onAllDesktopsButtonOnLeft ? TQColor(g.background().light(130)) : g.background();
- g2 = options()->colorGroup( ColorButtonBg, true );
+ g2 = options()->tqcolorGroup( ColorButtonBg, true );
pinUpPix = new KPixmap();
pinUpPix->resize(16, 16);
@@ -335,9 +335,9 @@ void QuartzHandler::createPixmaps()
// Inactive pins
- g = options()->colorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, false );
+ g = options()->tqcolorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, false );
c = onAllDesktopsButtonOnLeft ? TQColor(g.background().light(130)) : g.background();
- g2 = options()->colorGroup( ColorButtonBg, false );
+ g2 = options()->tqcolorGroup( ColorButtonBg, false );
ipinUpPix = new KPixmap();
ipinUpPix->resize(16, 16);
@@ -437,7 +437,7 @@ void QuartzButton::setBitmap(const unsigned char *bitmap)
if (bitmap) {
deco = new TQBitmap(10, 10, bitmap, true);
deco->setMask( *deco );
- repaint( false );
+ tqrepaint( false );
}
}
@@ -643,8 +643,8 @@ void QuartzClient::reset( unsigned long changed )
{
if (changed & SettingColors || changed & SettingFont)
{
- // repaint the whole thing
- widget()->repaint(false);
+ // tqrepaint the whole thing
+ widget()->tqrepaint(false);
}
KCommonDecoration::reset(changed);
@@ -675,9 +675,9 @@ void QuartzClient::paintEvent( TQPaintEvent* )
// Draw part of the frame that is the title color
if( coloredFrame )
- g = options()->colorGroup(ColorTitleBar, isActive());
+ g = options()->tqcolorGroup(ColorTitleBar, isActive());
else
- g = options()->colorGroup(ColorFrame, isActive());
+ g = options()->tqcolorGroup(ColorFrame, isActive());
// Draw outer highlights and lowlights
p.setPen( g.light().light(120) );